@@ -19,7 +19,9 @@ package validation
 import (
 	"net"
 	"testing"
+	"time"
 
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/util/intstr"
 	"k8s.io/apimachinery/pkg/util/sets"
 	"k8s.io/apimachinery/pkg/util/validation"
@@ -339,23 +341,60 @@ func TestValidateKubeAPIServer(t *testing.T) {
 	}
 }
 
-func Test_Validate_DockerConfig_Storage(t *testing.T) {
-	for _, name := range []string{"aufs", "zfs", "overlay"} {
-		config := &kops.DockerConfig{Storage: &name}
-		errs := validateDockerConfig(config, field.NewPath("docker"))
-		if len(errs) != 0 {
-			t.Fatalf("Unexpected errors validating DockerConfig %q", errs)
-		}
+func TestValidateKubeControllermanager(t *testing.T) {
+	grid := []struct {
+		Input          kops.KubeControllerManagerConfig
+		Cluster        *kops.Cluster
+		ExpectedErrors []string
+		ExpectedDetail string
+	}{
+		{
+			Input: kops.KubeControllerManagerConfig{
+				ExperimentalClusterSigningDuration: &metav1.Duration{Duration: time.Hour},
+			},
+			ExpectedErrors: []string{
+				"Forbidden::kubeControllerManager.experimentalClusterSigningDuration",
+			},
+			ExpectedDetail: "experimentalClusterSigningDuration has been replaced with clusterSigningDuration as of kubernetes 1.25",
+		},
+		{
+			Input: kops.KubeControllerManagerConfig{
+				ExperimentalClusterSigningDuration: &metav1.Duration{Duration: time.Hour},
+			},
+			Cluster: &kops.Cluster{
+				Spec: kops.ClusterSpec{
+					KubernetesVersion: "1.24.0",
+				},
+			},
+			ExpectedErrors: []string{},
+		},
 	}
-
-	for _, name := range []string{"overlayfs", "", "au"} {
-		config := &kops.DockerConfig{Storage: &name}
-		errs := validateDockerConfig(config, field.NewPath("docker"))
-		if len(errs) != 1 {
-			t.Fatalf("Expected errors validating DockerConfig %+v", config)
+	for _, g := range grid {
+		if g.Cluster == nil {
+			g.Cluster = &kops.Cluster{
+				Spec: kops.ClusterSpec{
+					KubernetesVersion: "1.28.0",
+				},
+			}
 		}
-		if errs[0].Field != "docker.storage" || errs[0].Type != field.ErrorTypeNotSupported {
-			t.Fatalf("Not the expected error validating DockerConfig %q", errs)
+		errs := validateKubeControllerManager(&g.Input, g.Cluster, field.NewPath("kubeControllerManager"), true)
+
+		testErrors(t, g.Input, errs, g.ExpectedErrors)
+
+		if g.ExpectedDetail != "" {
+			found := false
+			for _, err := range errs {
+				if err.Detail == g.ExpectedDetail {
+					found = true
+				}
+			}
+			if !found {
+				for _, err := range errs {
+					t.Logf("found detail: %q", err.Detail)
+				}
+
+				t.Errorf("did not find expected error %q", g.ExpectedDetail)
+			}
 		}
 	}
 }
@@ -1093,7 +1132,26 @@ func Test_Validate_Cilium(t *testing.T) {
 		},
 		{
 			Cilium: kops.CiliumNetworkingSpec{
-				Version: "v1.13.5",
+				Version: "v1.15.0",
+				Ingress: &kops.CiliumIngressSpec{
+					Enabled:                 fi.PtrTo(true),
+					DefaultLoadBalancerMode: "bad-value",
+				},
+			},
+			ExpectedErrors: []string{"Unsupported value::cilium.ingress.defaultLoadBalancerMode"},
+		},
+		{
+			Cilium: kops.CiliumNetworkingSpec{
+				Version: "v1.15.0",
+				Ingress: &kops.CiliumIngressSpec{
+					Enabled:                 fi.PtrTo(true),
+					DefaultLoadBalancerMode: "dedicated",
+				},
+			},
+		},
+		{
+			Cilium: kops.CiliumNetworkingSpec{
+				Version: "v1.15.0",
 				Hubble: &kops.HubbleSpec{
 					Enabled: fi.PtrTo(true),
 				},
@@ -1560,7 +1618,6 @@ func Test_Validate_Nvidia_Cluster(t *testing.T) {
 				CloudProvider: kops.CloudProviderSpec{
 					AWS: &kops.AWSSpec{},
 				},
-				ContainerRuntime: "containerd",
 			},
 		},
 		{
@@ -1573,7 +1630,6 @@ func Test_Validate_Nvidia_Cluster(t *testing.T) {
 				CloudProvider: kops.CloudProviderSpec{
 					Openstack: &kops.OpenstackSpec{},
 				},
-				ContainerRuntime: "containerd",
 			},
 			ExpectedErrors: []string{"Forbidden::containerd.nvidiaGPU"},
 		},
@@ -1587,21 +1643,6 @@ func Test_Validate_Nvidia_Cluster(t *testing.T) {
 				CloudProvider: kops.CloudProviderSpec{
 					GCE: &kops.GCESpec{},
 				},
-				ContainerRuntime: "containerd",
-			},
-			ExpectedErrors: []string{"Forbidden::containerd.nvidiaGPU"},
-		},
-		{
-			Input: kops.ClusterSpec{
-				Containerd: &kops.ContainerdConfig{
-					NvidiaGPU: &kops.NvidiaGPUConfig{
-						Enabled: fi.PtrTo(true),
-					},
-				},
-				CloudProvider: kops.CloudProviderSpec{
-					AWS: &kops.AWSSpec{},
-				},
-				ContainerRuntime: "docker",
 			},
 			ExpectedErrors: []string{"Forbidden::containerd.nvidiaGPU"},
 		},
@@ -1627,7 +1668,6 @@ func Test_Validate_Nvidia_Ig(t *testing.T) {
 				CloudProvider: kops.CloudProviderSpec{
 					AWS: &kops.AWSSpec{},
 				},
-				ContainerRuntime: "containerd",
 			},
 		},
 		{
@@ -1640,7 +1680,6 @@ func Test_Validate_Nvidia_Ig(t *testing.T) {
 				CloudProvider: kops.CloudProviderSpec{
 					Openstack: &kops.OpenstackSpec{},
 				},
-				ContainerRuntime: "containerd",
 			},
 		},
 		{
@@ -1653,21 +1692,6 @@ func Test_Validate_Nvidia_Ig(t *testing.T) {
 				CloudProvider: kops.CloudProviderSpec{
 					GCE: &kops.GCESpec{},
 				},
-				ContainerRuntime: "containerd",
-			},
-			ExpectedErrors: []string{"Forbidden::containerd.nvidiaGPU"},
-		},
-		{
-			Input: kops.ClusterSpec{
-				Containerd: &kops.ContainerdConfig{
-					NvidiaGPU: &kops.NvidiaGPUConfig{
-						Enabled: fi.PtrTo(true),
-					},
-				},
-				CloudProvider: kops.CloudProviderSpec{
-					AWS: &kops.AWSSpec{},
-				},
-				ContainerRuntime: "docker",
 			},
 			ExpectedErrors: []string{"Forbidden::containerd.nvidiaGPU"},
 		},
@@ -1677,3 +1701,70 @@ func Test_Validate_Nvidia_Ig(t *testing.T) {
 		testErrors(t, g.Input, errs, g.ExpectedErrors)
 	}
 }
+
+func Test_Validate_NriConfig(t *testing.T) {
+	unsupportedContainerdVersion := "1.6.0"
+	supportedContainerdVersion := "1.7.0"
+	grid := []struct {
+		Input          kops.ClusterSpec
+		ExpectedErrors []string
+	}{
+		{
+			Input: kops.ClusterSpec{
+				Containerd: &kops.ContainerdConfig{
+					NRI: &kops.NRIConfig{
+						Enabled: fi.PtrTo(true),
+					},
+					Version: &unsupportedContainerdVersion,
+				},
+			},
+			ExpectedErrors: []string{"Forbidden::containerd.nri"},
+		},
+		{
+			Input: kops.ClusterSpec{
+				Containerd: &kops.ContainerdConfig{
+					NRI:     &kops.NRIConfig{},
+					Version: &unsupportedContainerdVersion,
+				},
+			},
+			ExpectedErrors: []string{},
+		},
+		{
+			Input: kops.ClusterSpec{
+				Containerd: &kops.ContainerdConfig{
+					NRI: &kops.NRIConfig{
+						Enabled: nil,
+					},
+					Version: &unsupportedContainerdVersion,
+				},
+			},
+			ExpectedErrors: []string{},
+		},
+		{
+			Input: kops.ClusterSpec{
+				Containerd: &kops.ContainerdConfig{
+					NRI: &kops.NRIConfig{
+						Enabled: fi.PtrTo(false),
+					},
+					Version: &unsupportedContainerdVersion,
+				},
+			},
+			ExpectedErrors: []string{},
+		},
+		{
+			Input: kops.ClusterSpec{
+				Containerd: &kops.ContainerdConfig{
+					NRI: &kops.NRIConfig{
+						Enabled: fi.PtrTo(true),
+					},
+					Version: &supportedContainerdVersion,
+				},
+			},
+			ExpectedErrors: []string{},
+		},
+	}
+	for _, g := range grid {
+		errs := validateNriConfig(g.Input.Containerd, field.NewPath("containerd", "nri"))
+		testErrors(t, g.Input.Containerd, errs, g.ExpectedErrors)
+	}
+}
