@@ -17,6 +17,7 @@ limitations under the License.
 package aws
 
 import (
+	"context"
 	"errors"
 	"fmt"
 	"strings"
@@ -49,7 +50,7 @@ const (
 	TypeTargetGroup             = "target-group"
 )
 
-type listFn func(fi.Cloud, string) ([]*resources.Resource, error)
+type listFn func(fi.Cloud, string, string) ([]*resources.Resource, error)
 
 func ListResourcesAWS(cloud awsup.AWSCloud, clusterInfo resources.ClusterInfo) (map[string]*resources.Resource, error) {
 	clusterName := clusterInfo.Name
@@ -72,18 +73,15 @@ func ListResourcesAWS(cloud awsup.AWSCloud, clusterInfo resources.ClusterInfo) (
 		ListEgressOnlyInternetGateways,
 		ListRouteTables,
 		ListSubnets,
-		ListVPCs,
 		ListENIs,
 		// ELBs
 		ListELBs,
 		ListELBV2s,
 		ListTargetGroups,
-
 		// IAM
 		ListIAMInstanceProfiles,
 		ListIAMRoles,
 		ListIAMOIDCProviders,
-
 		// SQS
 		ListSQSQueues,
 		// EventBridge
@@ -100,8 +98,21 @@ func ListResourcesAWS(cloud awsup.AWSCloud, clusterInfo resources.ClusterInfo) (
 		listFunctions = append(listFunctions, ListSpotinstResources)
 	}
 
+	var vpcID string
+	{
+		r, err := ListVPCs(cloud, clusterName)
+		if err != nil {
+			return nil, err
+		}
+
+		if len(r) > 0 {
+			vpcID = r[0].ID
+			resourceTrackers[r[0].Type+":"+r[0].ID] = r[0]
+		}
+	}
+
 	for _, fn := range listFunctions {
-		rt, err := fn(cloud, clusterName)
+		rt, err := fn(cloud, vpcID, clusterName)
 		if err != nil {
 			return nil, err
 		}
@@ -132,7 +143,9 @@ func ListResourcesAWS(cloud awsup.AWSCloud, clusterInfo resources.ClusterInfo) (
 					resourceTrackers["internet-gateway:"+igwID] = &resources.Resource{
 						Name:    FindName(igw.Tags),
 						ID:      igwID,
+						Obj:     igw,
 						Type:    "internet-gateway",
+						Dumper:  DumpInternetGateway,
 						Deleter: DeleteInternetGateway,
 						Shared:  vpc.Shared, // Shared iff the VPC is shared
 					}
@@ -305,35 +318,42 @@ func matchesIAMTags(tags map[string]string, actual []*iam.Tag) bool {
 	return true
 }
 
-//type DeletableResource interface {
-//	Delete(cloud fi.Cloud) error
-//}
-
-func DeleteInstance(cloud fi.Cloud, t *resources.Resource) error {
+func DeleteInstances(cloud fi.Cloud, t []*resources.Resource) error {
 	c := cloud.(awsup.AWSCloud)
 
-	id := t.ID
-	klog.V(2).Infof("Deleting EC2 instance %q", id)
-	request := &ec2.TerminateInstancesInput{
-		InstanceIds: []*string{&id},
-	}
-	_, err := c.EC2().TerminateInstances(request)
-	if err != nil {
-		if awsup.AWSErrorCode(err) == "InvalidInstanceID.NotFound" {
-			klog.V(2).Infof("Got InvalidInstanceID.NotFound error deleting instance %q; will treat as already-deleted", id)
-		} else {
-			return fmt.Errorf("error deleting Instance %q: %v", id, err)
+	var ids []*string
+	for i, instance := range t {
+		ids = append(ids, &instance.ID)
+		if len(ids) < 100 && i < len(t)-1 {
+			continue
+		}
+
+		klog.Infof("Terminating %d EC2 instances", len(ids))
+		request := &ec2.TerminateInstancesInput{
+			InstanceIds: ids,
+		}
+		ids = []*string{}
+		_, err := c.EC2().TerminateInstances(request)
+		if err != nil {
+			if awsup.AWSErrorCode(err) == "InvalidInstanceID.NotFound" {
+				klog.V(2).Infof("Got InvalidInstanceID.NotFound error terminating instances; will treat as already terminated")
+			} else {
+				return fmt.Errorf("error terminating instances: %v", err)
+			}
 		}
 	}
 	return nil
 }
 
-func ListInstances(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func ListInstances(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	c := cloud.(awsup.AWSCloud)
 
 	klog.V(2).Infof("Querying EC2 instances")
+	filters := BuildEC2Filters(cloud)
+	filters = append(filters, awsup.NewEC2Filter("vpc-id", vpcID))
+	filters = append(filters, awsup.NewEC2Filter("instance-state-name", ec2.InstanceStateNameRunning))
 	request := &ec2.DescribeInstancesInput{
-		Filters: BuildEC2Filters(cloud),
+		Filters: filters,
 	}
 
 	var resourceTrackers []*resources.Resource
@@ -343,28 +363,14 @@ func ListInstances(cloud fi.Cloud, clusterName string) ([]*resources.Resource, e
 			for _, instance := range reservation.Instances {
 				id := aws.StringValue(instance.InstanceId)
 
-				if instance.State != nil {
-					stateName := aws.StringValue(instance.State.Name)
-					switch stateName {
-					case "terminated", "shutting-down":
-						continue
-
-					case "running", "stopped", "pending":
-						// We need to delete
-						klog.V(4).Infof("instance %q has state=%q", id, stateName)
-
-					default:
-						klog.Infof("unknown instance state for %q: %q", id, stateName)
-					}
-				}
-
 				resourceTracker := &resources.Resource{
-					Name:    FindName(instance.Tags),
-					ID:      id,
-					Type:    ec2.ResourceTypeInstance,
-					Deleter: DeleteInstance,
-					Dumper:  DumpInstance,
-					Obj:     instance,
+					Name:         FindName(instance.Tags),
+					ID:           id,
+					Type:         ec2.ResourceTypeInstance,
+					GroupDeleter: DeleteInstances,
+					GroupKey:     fi.ValueOf(instance.SubnetId),
+					Dumper:       DumpInstance,
+					Obj:          instance,
 				}
 
 				var blocks []string
@@ -372,7 +378,7 @@ func ListInstances(cloud fi.Cloud, clusterName string) ([]*resources.Resource, e
 				blocks = append(blocks, "vpc:"+aws.StringValue(instance.VpcId))
 
 				for _, volume := range instance.BlockDeviceMappings {
-					if volume.Ebs == nil {
+					if volume.Ebs == nil || fi.ValueOf(volume.Ebs.DeleteOnTermination) {
 						continue
 					}
 					blocks = append(blocks, "volume:"+aws.StringValue(volume.Ebs.VolumeId))
@@ -384,7 +390,6 @@ func ListInstances(cloud fi.Cloud, clusterName string) ([]*resources.Resource, e
 				resourceTracker.Blocks = blocks
 
 				resourceTrackers = append(resourceTrackers, resourceTracker)
-
 			}
 		}
 		return true
@@ -548,7 +553,7 @@ func DeleteVolume(cloud fi.Cloud, r *resources.Resource) error {
 	return nil
 }
 
-func ListVolumes(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func ListVolumes(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	c := cloud.(awsup.AWSCloud)
 
 	volumes, err := DescribeVolumes(cloud)
@@ -659,7 +664,7 @@ func DeleteKeypair(cloud fi.Cloud, r *resources.Resource) error {
 	return nil
 }
 
-func ListKeypairs(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func ListKeypairs(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	if !strings.Contains(clusterName, ".") {
 		klog.Infof("cluster %q is legacy (kube-up) cluster; won't delete keypairs", clusterName)
 		return nil, nil
@@ -722,7 +727,7 @@ func DeleteSubnet(cloud fi.Cloud, tracker *resources.Resource) error {
 	return nil
 }
 
-func ListSubnets(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func ListSubnets(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	c := cloud.(awsup.AWSCloud)
 	subnets, err := DescribeSubnets(cloud)
 	if err != nil {
@@ -801,12 +806,12 @@ func ListSubnets(cloud fi.Cloud, clusterName string) ([]*resources.Resource, err
 
 		rtRequest := &ec2.DescribeRouteTablesInput{}
 		rtResponse, err := c.EC2().DescribeRouteTables(rtRequest)
-		if err != nil {
+		if err != nil && awsup.AWSErrorCode(err) != "InvalidRouteTableID.NotFound" {
 			return nil, fmt.Errorf("error describing RouteTables: %v", err)
 		}
 		// sharedNgwIds is the set of IDs for shared NGWs, that we should not delete
 		sharedNgwIds := sets.NewString()
-		{
+		if rtResponse != nil {
 			for _, rt := range rtResponse.RouteTables {
 				for _, t := range rt.Tags {
 					k := aws.StringValue(t.Key)
@@ -916,7 +921,7 @@ func DeleteDhcpOptions(cloud fi.Cloud, r *resources.Resource) error {
 	return nil
 }
 
-func ListDhcpOptions(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func ListDhcpOptions(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	dhcpOptions, err := DescribeDhcpOptions(cloud)
 	if err != nil {
 		return nil, err
@@ -1022,7 +1027,16 @@ func DeleteInternetGateway(cloud fi.Cloud, r *resources.Resource) error {
 	return nil
 }
 
-func ListInternetGateways(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func DumpInternetGateway(op *resources.DumpOperation, r *resources.Resource) error {
+	data := make(map[string]interface{})
+	data["id"] = r.ID
+	data["type"] = r.Type
+	data["raw"] = r.Obj
+	op.Dump.Resources = append(op.Dump.Resources, data)
+	return nil
+}
+
+func ListInternetGateways(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	gateways, err := DescribeInternetGateways(cloud)
 	if err != nil {
 		return nil, err
@@ -1091,6 +1105,15 @@ func DescribeInternetGatewaysIgnoreTags(cloud fi.Cloud) ([]*ec2.InternetGateway,
 	return gateways, nil
 }
 
+func DumpEgressOnlyInternetGateway(op *resources.DumpOperation, r *resources.Resource) error {
+	data := make(map[string]interface{})
+	data["id"] = r.ID
+	data["type"] = r.Type
+	data["raw"] = r.Obj
+	op.Dump.Resources = append(op.Dump.Resources, data)
+	return nil
+}
+
 func DeleteEgressOnlyInternetGateway(cloud fi.Cloud, r *resources.Resource) error {
 	c := cloud.(awsup.AWSCloud)
 
@@ -1117,7 +1140,7 @@ func DeleteEgressOnlyInternetGateway(cloud fi.Cloud, r *resources.Resource) erro
 	return nil
 }
 
-func ListEgressOnlyInternetGateways(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func ListEgressOnlyInternetGateways(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	gateways, err := DescribeEgressOnlyInternetGateways(cloud)
 	if err != nil {
 		return nil, err
@@ -1130,6 +1153,8 @@ func ListEgressOnlyInternetGateways(cloud fi.Cloud, clusterName string) ([]*reso
 			Name:    FindName(o.Tags),
 			ID:      aws.StringValue(o.EgressOnlyInternetGatewayId),
 			Type:    "egress-only-internet-gateway",
+			Obj:     o,
+			Dumper:  DumpEgressOnlyInternetGateway,
 			Deleter: DeleteEgressOnlyInternetGateway,
 			Shared:  HasSharedTag(ec2.ResourceTypeEgressOnlyInternetGateway+":"+aws.StringValue(o.EgressOnlyInternetGatewayId), o.Tags, clusterName),
 		}
@@ -1167,6 +1192,8 @@ func DescribeEgressOnlyInternetGateways(cloud fi.Cloud) ([]*ec2.EgressOnlyIntern
 }
 
 func DeleteAutoScalingGroup(cloud fi.Cloud, r *resources.Resource) error {
+	ctx := context.TODO()
+
 	c := cloud.(awsup.AWSCloud)
 
 	id := r.ID
@@ -1176,7 +1203,7 @@ func DeleteAutoScalingGroup(cloud fi.Cloud, r *resources.Resource) error {
 		AutoScalingGroupName: &id,
 		ForceDelete:          aws.Bool(true),
 	}
-	_, err := c.Autoscaling().DeleteAutoScalingGroup(request)
+	_, err := c.Autoscaling().DeleteAutoScalingGroupWithContext(ctx, request)
 	if err != nil {
 		if IsDependencyViolation(err) {
 			return err
@@ -1186,7 +1213,7 @@ func DeleteAutoScalingGroup(cloud fi.Cloud, r *resources.Resource) error {
 	return nil
 }
 
-func ListAutoScalingGroups(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func ListAutoScalingGroups(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	c := cloud.(awsup.AWSCloud)
 
 	tags := c.Tags()
@@ -1278,32 +1305,34 @@ func FindNatGateways(cloud fi.Cloud, routeTables map[string]*resources.Resource,
 			request.RouteTableIds = append(request.RouteTableIds, aws.String(routeTable.ID))
 		}
 		response, err := c.EC2().DescribeRouteTables(request)
-		if err != nil {
+		if err != nil && awsup.AWSErrorCode(err) != "InvalidRouteTableID.NotFound" {
 			return nil, fmt.Errorf("error from DescribeRouteTables: %v", err)
 		}
-		for _, rt := range response.RouteTables {
-			routeTableID := aws.StringValue(rt.RouteTableId)
-			resource := routeTables[routeTableID]
-			if resource == nil {
-				// We somehow got a route table that we didn't ask for
-				klog.Warningf("unable to find resource for route table %s", routeTableID)
-				continue
-			}
-
-			shared := resource.Shared
-			for _, t := range rt.Tags {
-				k := *t.Key
-				// v := *t.Value
-				if k == "AssociatedNatgateway" {
-					shared = true
+		if response != nil {
+			for _, rt := range response.RouteTables {
+				routeTableID := aws.StringValue(rt.RouteTableId)
+				resource := routeTables[routeTableID]
+				if resource == nil {
+					// We somehow got a route table that we didn't ask for
+					klog.Warningf("unable to find resource for route table %s", routeTableID)
+					continue
 				}
-			}
 
-			for _, route := range rt.Routes {
-				if route.NatGatewayId != nil {
-					natGatewayIds.Insert(*route.NatGatewayId)
-					if !shared {
-						ownedNatGatewayIds.Insert(*route.NatGatewayId)
+				shared := resource.Shared
+				for _, t := range rt.Tags {
+					k := *t.Key
+					// v := *t.Value
+					if k == "AssociatedNatgateway" {
+						shared = true
+					}
+				}
+
+				for _, route := range rt.Routes {
+					if route.NatGatewayId != nil {
+						natGatewayIds.Insert(*route.NatGatewayId)
+						if !shared {
+							ownedNatGatewayIds.Insert(*route.NatGatewayId)
+						}
 					}
 				}
 			}
@@ -1443,7 +1472,7 @@ func DumpELB(op *resources.DumpOperation, r *resources.Resource) error {
 	return nil
 }
 
-func ListELBs(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func ListELBs(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	elbs, elbTags, err := DescribeELBs(cloud)
 	if err != nil {
 		return nil, err
@@ -1538,14 +1567,17 @@ func DescribeELBs(cloud fi.Cloud) ([]*elb.LoadBalancerDescription, map[string][]
 }
 
 // For NLBs and ALBs
-func ListELBV2s(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
-	elbv2s, _, err := DescribeELBV2s(cloud)
+func ListELBV2s(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
+	ctx := context.TODO()
+
+	loadBalancers, err := awsup.ListELBV2LoadBalancers(ctx, cloud.(awsup.AWSCloud))
 	if err != nil {
 		return nil, err
 	}
 
 	var resourceTrackers []*resources.Resource
-	for _, elb := range elbv2s {
+	for _, loadBalancer := range loadBalancers {
+		elb := loadBalancer.LoadBalancer
 		id := aws.StringValue(elb.LoadBalancerName)
 		resourceTracker := &resources.Resource{
 			Name:    id,
@@ -1571,80 +1603,31 @@ func ListELBV2s(cloud fi.Cloud, clusterName string) ([]*resources.Resource, erro
 	return resourceTrackers, nil
 }
 
-func DescribeELBV2s(cloud fi.Cloud) ([]*elbv2.LoadBalancer, map[string][]*elbv2.Tag, error) {
-	c := cloud.(awsup.AWSCloud)
-	tags := c.Tags()
-
-	klog.V(2).Infof("Listing all NLBs and ALBs")
-
-	request := &elbv2.DescribeLoadBalancersInput{}
-	// ELBV2 DescribeTags has a limit of 20 names, so we set the page size here to 20 also
-	request.PageSize = aws.Int64(20)
-
-	var elbv2s []*elbv2.LoadBalancer
-	elbv2Tags := make(map[string][]*elbv2.Tag)
-
-	var innerError error
-	err := c.ELBV2().DescribeLoadBalancersPages(request, func(p *elbv2.DescribeLoadBalancersOutput, lastPage bool) bool {
-		if len(p.LoadBalancers) == 0 {
-			return true
-		}
-
-		tagRequest := &elbv2.DescribeTagsInput{}
-
-		nameToELB := make(map[string]*elbv2.LoadBalancer)
-		for _, elb := range p.LoadBalancers {
-			name := aws.StringValue(elb.LoadBalancerArn)
-			nameToELB[name] = elb
-
-			tagRequest.ResourceArns = append(tagRequest.ResourceArns, elb.LoadBalancerArn)
-		}
-
-		tagResponse, err := c.ELBV2().DescribeTags(tagRequest)
-		if err != nil {
-			innerError = fmt.Errorf("error listing elb Tags: %v", err)
-			return false
-		}
-
-		for _, t := range tagResponse.TagDescriptions {
-
-			elbARN := aws.StringValue(t.ResourceArn)
-			if !matchesElbV2Tags(tags, t.Tags) {
-				continue
-			}
-
-			elbv2Tags[elbARN] = t.Tags
-			elb := nameToELB[elbARN]
-			elbv2s = append(elbv2s, elb)
-		}
-
-		return true
-	})
-	if err != nil {
-		return nil, nil, fmt.Errorf("error describing LoadBalancers: %v", err)
-	}
-	if innerError != nil {
-		return nil, nil, fmt.Errorf("error describing LoadBalancers: %v", innerError)
-	}
-
-	return elbv2s, elbv2Tags, nil
+func DumpTargetGroup(op *resources.DumpOperation, r *resources.Resource) error {
+	data := make(map[string]interface{})
+	data["id"] = r.ID
+	data["type"] = TypeTargetGroup
+	data["raw"] = r.Obj
+	op.Dump.Resources = append(op.Dump.Resources, data)
+	return nil
 }
 
-func ListTargetGroups(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
-	targetgroups, _, err := DescribeTargetGroups(cloud)
+func ListTargetGroups(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
+	targetGroups, err := listMatchingTargetGroups(cloud)
 	if err != nil {
 		return nil, err
 	}
 
 	var resourceTrackers []*resources.Resource
-	for _, tg := range targetgroups {
+	for _, targetGroup := range targetGroups {
+		tg := targetGroup.TargetGroup
 		id := aws.StringValue(tg.TargetGroupName)
 		resourceTracker := &resources.Resource{
 			Name:    id,
-			ID:      string(*tg.TargetGroupArn),
+			ID:      targetGroup.ARN,
 			Type:    TypeTargetGroup,
 			Deleter: DeleteTargetGroup,
-			Dumper:  DumpELB,
+			Dumper:  DumpTargetGroup,
 			Obj:     tg,
 		}
 
@@ -1653,62 +1636,27 @@ func ListTargetGroups(cloud fi.Cloud, clusterName string) ([]*resources.Resource
 	return resourceTrackers, nil
 }
 
-func DescribeTargetGroups(cloud fi.Cloud) ([]*elbv2.TargetGroup, map[string][]*elbv2.Tag, error) {
+func listMatchingTargetGroups(cloud fi.Cloud) ([]*awsup.TargetGroupInfo, error) {
+	ctx := context.TODO()
+
 	c := cloud.(awsup.AWSCloud)
 	tags := c.Tags()
 
 	klog.V(2).Infof("Listing all TargetGroups")
 
-	request := &elbv2.DescribeTargetGroupsInput{}
-	// DescribeTags has a limit of 20 names, so we set the page size here to 20 also
-	request.PageSize = aws.Int64(20)
-
-	var targetgroups []*elbv2.TargetGroup
-	targetgroupTags := make(map[string][]*elbv2.Tag)
-
-	var innerError error
-	err := c.ELBV2().DescribeTargetGroupsPages(request, func(p *elbv2.DescribeTargetGroupsOutput, lastPage bool) bool {
-		if len(p.TargetGroups) == 0 {
-			return true
-		}
-
-		tagRequest := &elbv2.DescribeTagsInput{}
-
-		nameToTargetGroup := make(map[string]*elbv2.TargetGroup)
-		for _, tg := range p.TargetGroups {
-			name := aws.StringValue(tg.TargetGroupArn)
-			nameToTargetGroup[name] = tg
-
-			tagRequest.ResourceArns = append(tagRequest.ResourceArns, tg.TargetGroupArn)
-		}
-
-		tagResponse, err := c.ELBV2().DescribeTags(tagRequest)
-		if err != nil {
-			innerError = fmt.Errorf("error listing TargetGroup Tags: %v", err)
-			return false
-		}
-
-		for _, t := range tagResponse.TagDescriptions {
-			tgARN := aws.StringValue(t.ResourceArn)
-			if !matchesElbV2Tags(tags, t.Tags) {
-				continue
-			}
-			targetgroupTags[tgARN] = t.Tags
-
-			tg := nameToTargetGroup[tgARN]
-			targetgroups = append(targetgroups, tg)
-		}
-
-		return true
-	})
+	targetGroups, err := awsup.ListELBV2TargetGroups(ctx, c)
 	if err != nil {
-		return nil, nil, fmt.Errorf("error describing TargetGroups: %v", err)
-	}
-	if innerError != nil {
-		return nil, nil, fmt.Errorf("error describing TargetGroups: %v", innerError)
+		return nil, err
 	}
 
-	return targetgroups, targetgroupTags, nil
+	var matches []*awsup.TargetGroupInfo
+	for _, tg := range targetGroups {
+		if matchesElbV2Tags(tags, tg.Tags) {
+			matches = append(matches, tg)
+		}
+	}
+
+	return matches, nil
 }
 
 func DeleteElasticIP(cloud fi.Cloud, t *resources.Resource) error {
@@ -1783,7 +1731,7 @@ func deleteRoute53Records(cloud fi.Cloud, zone *route53.HostedZone, resourceTrac
 	return nil
 }
 
-func ListRoute53Records(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func ListRoute53Records(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	var resourceTrackers []*resources.Resource
 
 	c := cloud.(awsup.AWSCloud)
@@ -1966,7 +1914,7 @@ func DeleteIAMRole(cloud fi.Cloud, r *resources.Resource) error {
 	return nil
 }
 
-func ListIAMRoles(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func ListIAMRoles(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	c := cloud.(awsup.AWSCloud)
 
 	var resourceTrackers []*resources.Resource
@@ -2056,7 +2004,7 @@ func DeleteIAMInstanceProfile(cloud fi.Cloud, r *resources.Resource) error {
 	return nil
 }
 
-func ListIAMInstanceProfiles(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func ListIAMInstanceProfiles(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	c := cloud.(awsup.AWSCloud)
 
 	var getProfileErr error
@@ -2114,7 +2062,7 @@ func ListIAMInstanceProfiles(cloud fi.Cloud, clusterName string) ([]*resources.R
 	return resourceTrackers, nil
 }
 
-func ListIAMOIDCProviders(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func ListIAMOIDCProviders(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	c := cloud.(awsup.AWSCloud)
 	tags := c.Tags()
 
@@ -2180,7 +2128,7 @@ func DeleteIAMOIDCProvider(cloud fi.Cloud, r *resources.Resource) error {
 	return nil
 }
 
-func ListSpotinstResources(cloud fi.Cloud, clusterName string) ([]*resources.Resource, error) {
+func ListSpotinstResources(cloud fi.Cloud, vpcID, clusterName string) ([]*resources.Resource, error) {
 	return spotinst.ListResources(cloud.(awsup.AWSCloud).Spotinst(), clusterName)
 }
 
